@@ -1,12 +1,12 @@
 package Config::IOD::Base;
 
-our $DATE = '2015-03-27'; # DATE
-our $VERSION = '0.15'; # VERSION
+our $DATE = '2015-05-05'; # DATE
+our $VERSION = '0.16'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Carp;
+#use Carp; # avoided to shave a bit of startup time
 
 use constant +{
     COL_V_ENCODING => 0, # either "!j" or '"', '[', '{'
@@ -108,7 +108,7 @@ sub _parse_command_line {
 
 # return ($err, $res, $decoded_val)
 sub _parse_raw_value {
-    use experimental 'smartmatch';
+    no warnings; # XXX no warnings 'experimental::smartmatch', but this is unrecognized in 5.10
 
     my ($self, $val, $needs_res) = @_;
 
@@ -346,7 +346,7 @@ sub _decode_expr {
 
 sub _err {
     my ($self, $msg) = @_;
-    croak join(
+    die join(
         "",
         @{ $self->{_include_stack} } ? "$self->{_include_stack}[0] " : "",
         "line $self->{_linum}: ",
@@ -377,7 +377,7 @@ sub _push_include_stack {
 sub _pop_include_stack {
     my $self = shift;
 
-    croak "BUG: Overpopped _pop_include_stack"
+    die "BUG: Overpopped _pop_include_stack"
         unless @{$self->{_include_stack}};
     pop @{ $self->{_include_stack} };
 }
@@ -391,7 +391,7 @@ sub _init_read {
 sub _read_file {
     my ($self, $filename) = @_;
     open my $fh, "<", $filename
-        or croak "Can't open file '$filename': $!";
+        or die "Can't open file '$filename': $!";
     binmode($fh, ":utf8");
     local $/;
     return ~~<$fh>;
@@ -401,7 +401,7 @@ sub read_file {
     my ($self, $filename) = @_;
     $self->_init_read;
     my $res = $self->_push_include_stack($filename);
-    croak "Can't read '$filename': $res->[1]" unless $res->[0] == 200;
+    die "Can't read '$filename': $res->[1]" unless $res->[0] == 200;
     $res =
         $self->_read_string($self->_read_file($filename));
     $self->_pop_include_stack;
@@ -429,7 +429,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.15 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-03-27.
+This document describes version 0.16 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-05-05.
 
 =head1 ATTRIBUTES
 
